@@ -17,7 +17,7 @@ if __name__ == "__main__":
 
 from define import *
 from test_handler.calibration import crop_rotate
-
+from test_handler.qr_identify import qrIdentify
 
 def camInstCreate(cameraIndex):
     try:
@@ -35,18 +35,32 @@ def camInstCreate(cameraIndex):
 camera_sem = threading.Semaphore()
 def takePhoto(cameraIndex,qrCode,event):
     rtn = None
+    print('in takePhoto')
     for i in range(5):
         camera_sem.acquire()    
         try:
             cam=camInstCreate(cameraIndex)
             s, img=cam.read()
             if s:
-                photo=qrCode+'_'+str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg'
-                imageFile=IMG_PATH+photo
-                if crop_rotate(img,imageFile):
+                print('got image')
+                if qrCode!=None:   ## got Qr code, regular picture for detection.
+                    photo=qrCode+'_'+str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg'
+                    imageFile=IMG_PATH+photo
+                    if crop_rotate(img,imageFile):
+                        cam.release()
+                        camera_sem.release()
+                        rtn=photo
+                        break;
+                else: ## No Qr code, identify it from image.
+                    print('qr image')
+                    #cv2.imwrite(str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg', img)
+                    photo=qrIdentify(img);
                     cam.release()
                     camera_sem.release()
-                    rtn=photo
+                    if photo == None:
+                        rtn=NON_QR
+                    else:
+                        rtn=photo
                     break;
             else:
                 print("Photo taking failed!",qrCode, time.strftime('%Y%m%d%H%M%S'))
@@ -94,16 +108,21 @@ class TakePhotoProcedure(threading.Thread):
                 #print(time.strftime('%Y%m%d%H%M%S'), "got stop command")
                 break;
             
-    def procedure(self,photoIndex):        
-        photoFile=takePhoto(self.camera, self.qrCode+'_'+str(self.slotIndex)+'_'+str(photoIndex), self.event)
+    def procedure(self,photoIndex):
+        if self.qrCode != None:
+            photoFile=takePhoto(self.camera, self.qrCode+'_'+str(self.slotIndex)+'_'+str(photoIndex), self.event)
+        else:
+            photoFile=takePhoto(self.camera, None, self.event) ## For Qr code
         if(photoFile !=None ):
             print(photoFile)
             self.qCom.put(photoFile)
         
+        
    
 def takePhoto_test():
-    cameraIndex = 6
-    qrCode ='8888'
+    cameraIndex = 4
+#    qrCode ='8888'
+    qrCode =None
     stopTakingPhoto = threading.Event()
     stopTakingPhoto.set()
     print (takePhoto(cameraIndex,qrCode,stopTakingPhoto) )
